@@ -1,9 +1,10 @@
-# pylint: disable=too-many-arguments
+# pylint: disable=too-many-arguments,too-many-locals,too-many-statements
 from __future__ import annotations
 
 import asyncio
+import threading
 import time
-from os import getenv
+from os import _exit, getenv
 from socket import socket
 from typing import Optional
 
@@ -95,8 +96,6 @@ def main(
 
     # When metrics are enabled, let's ensure that datadog-agent is running first...
     if not no_metrics():  # pragma: no cover
-        import logging
-
         logger = logging.root
         conn: Optional[socket] = None
         connected = False
@@ -111,23 +110,42 @@ def main(
                 logger.info("waiting for statsd server to finish initialization...")
                 time.sleep(5)
             except Exception as e:
-                logger.info(f"statsd connection error: {e}, retrying...")
+                logger.info("statsd connection error: %s, retrying...", str(e))
                 time.sleep(1)
             finally:
                 assert conn is not None
                 conn.close()
 
-    loop = asyncio.new_event_loop()
-    if debug:
-        loop.set_debug(True)
     if api:
         from .web import launch_web_server
 
+        loop = asyncio.new_event_loop()
+        loop.set_debug(debug)
         launch_web_server(settings, loop, port or settings.PORT)
         loop.run_forever()
     else:
+        from . import SpellBot
         from .client import build_bot
 
         assert settings.BOT_TOKEN is not None
-        bot = build_bot(loop=loop, mock_games=mock_games)
+        bot = build_bot(mock_games=mock_games)
+
+        if not debug and not running_in_pytest:
+            # Sometimes the bot gets into a weird state where it doesn't properly
+            # start up entirely; this causes tasks (see tasks_cog.py) to never begin
+            # since those only start after the ready signal has been processed.
+            # As such, let's check every 30 minutes if the bot is ready, because if
+            # it isn't we can just kill it and have supervisord restart it for us.
+            def killer(bot: SpellBot):
+                while True:
+                    time.sleep(30 * 60)  # 30 minute wait
+                    if not bot.is_ready():
+                        print("exiting due to readiness check failure")  # noqa: T201
+                        _exit(1)
+                    else:
+                        print("readiness check passed")  # noqa: T201
+
+            x = threading.Thread(target=killer, args=(bot,))
+            x.start()
+
         bot.run(settings.BOT_TOKEN)
