@@ -39,6 +39,10 @@ class ChannelsService:
         channel = DatabaseSession.query(Channel).filter(Channel.xid == channel.id).one()
         return channel.to_dict()
 
+    @sync_to_async
+    def forget(self, xid: int) -> None:
+        DatabaseSession.query(Channel).filter(Channel.xid == xid).delete(synchronize_session=False)
+
     @sync_to_async
     def select(self, xid: int) -> Optional[dict[str, Any]]:
         channel = DatabaseSession.query(Channel).filter(Channel.xid == xid).one_or_none()
